@@ -42,11 +42,7 @@ def test_post_defaults(mock_post, mock_uuid, capsys):
         'status': 'Hello world',
         'visibility': 'public',
         'media_ids': [],
-        'sensitive': "false",
-        'spoiler_text': None,
-        'in_reply_to_id': None,
-        'language': None,
-        'scheduled_at': None,
+        'sensitive': False,
     }, headers={"Idempotency-Key": "rock-on"})
 
     out, err = capsys.readouterr()
@@ -65,7 +61,7 @@ def test_post_with_options(mock_post, mock_uuid, capsys):
         '--sensitive',
         '--spoiler-text', 'Spoiler!',
         '--reply-to', '123a',
-        '--language', 'hrv',
+        '--language', 'hr',
     ]
 
     mock_post.return_value = MockResponse({
@@ -78,11 +74,10 @@ def test_post_with_options(mock_post, mock_uuid, capsys):
         'status': 'Hello world',
         'media_ids': [],
         'visibility': 'unlisted',
-        'sensitive': "true",
+        'sensitive': True,
         'spoiler_text': "Spoiler!",
         'in_reply_to_id': '123a',
-        'language': 'hrv',
-        'scheduled_at': None,
+        'language': 'hr',
     }, headers={"Idempotency-Key": "up-the-irons"})
 
     out, err = capsys.readouterr()
@@ -477,7 +472,7 @@ def test_whoami(mock_get, capsys):
     assert "A developer." in out
     assert "https://mastodon.social/@ihabunek" in out
     assert "ID: 46103" in out
-    assert "Since: 2017-04-04 @ 13:23:09" in out
+    assert "Since: 2017-04-04" in out
     assert "Followers: 5" in out
     assert "Following: 9" in out
     assert "Statuses: 19" in out
@@ -572,21 +567,21 @@ def test_notifications(mock_get, capsys):
         "",
         "We still have fans in 2017 @fan123",
         "",
-        "ID 111111111111111111  ",
+        "ID 111111111111111111   ",
         "────────────────────────────────────────────────────────────────────────────────────────────────────",
         "Terry Bozzio @terry@bozzio.social reblogged your status",
         "Zappa Fan @fan123@zappa-fans.social                                             1983-11-04 15:53 UTC",
         "",
         "The Black Page, a masterpiece",
         "",
-        "ID 1234  ",
+        "ID 1234   ",
         "────────────────────────────────────────────────────────────────────────────────────────────────────",
         "Zappa Old Fan @fan9@zappa-fans.social favourited your status",
         "Zappa Fan @fan123@zappa-fans.social                                             1983-11-04 15:53 UTC",
         "",
         "The Black Page, a masterpiece",
         "",
-        "ID 1234  ",
+        "ID 1234   ",
         "────────────────────────────────────────────────────────────────────────────────────────────────────",
         "",
     ])
