@@ -112,7 +112,7 @@ def test_instance(app, run):
 
 
 def test_instance_anon(app, run_anon):
-    out = run_anon("instance", "--disable-https", "localhost:3000")
+    out = run_anon("instance", "--disable-https", HOSTNAME)
     assert "Mastodon" in out
     assert app.instance in out
     assert "running Mastodon" in out
@@ -130,13 +130,15 @@ def test_post(app, user, run):
 
     status = api.fetch_status(app, user, status_id)
     assert text == get_text(status["content"])
-    assert status["account"]["acct"] == user.username
-    assert status["application"]["name"] == CLIENT_NAME
-    assert status["application"]["website"] == CLIENT_WEBSITE
     assert status["visibility"] == "public"
     assert status["sensitive"] is False
     assert status["spoiler_text"] == ""
 
+    # Pleroma doesn't return the application
+    if status["application"]:
+        assert status["application"]["name"] == CLIENT_NAME
+        assert status["application"]["website"] == CLIENT_WEBSITE
+
 
 def test_post_visibility(app, user, run):
     for visibility in ["public", "unlisted", "private", "direct"]:
@@ -146,17 +148,62 @@ def test_post_visibility(app, user, run):
         assert status["visibility"] == visibility
 
 
-def test_post_scheduled(app, user, run):
+def test_post_scheduled_at(app, user, run):
+    text = str(uuid.uuid4())
     scheduled_at = datetime.now(timezone.utc).replace(microsecond=0) + timedelta(minutes=10)
 
-    out = run("post", "foo", "--scheduled-at", scheduled_at.isoformat())
+    out = run("post", text, "--scheduled-at", scheduled_at.isoformat())
     assert "Toot scheduled for" in out
 
-    [status] = api.scheduled_statuses(app, user)
-    assert status["params"]["text"] == "foo"
+    statuses = api.scheduled_statuses(app, user)
+    [status] = [s for s in statuses if s["params"]["text"] == text]
     assert datetime.strptime(status["scheduled_at"], "%Y-%m-%dT%H:%M:%S.%f%z") == scheduled_at
 
 
+def test_post_scheduled_in(app, user, run):
+    text = str(uuid.uuid4())
+
+    variants = [
+        ("1 day", timedelta(days=1)),
+        ("1 day 6 hours", timedelta(days=1, hours=6)),
+        ("1 day 6 hours 13 minutes", timedelta(days=1, hours=6, minutes=13)),
+        ("1 day 6 hours 13 minutes 51 second", timedelta(days=1, hours=6, minutes=13, seconds=51)),
+        ("2d", timedelta(days=2)),
+        ("2d6h", timedelta(days=2, hours=6)),
+        ("2d6h13m", timedelta(days=2, hours=6, minutes=13)),
+        ("2d6h13m51s", timedelta(days=2, hours=6, minutes=13, seconds=51)),
+    ]
+
+    datetimes = []
+    for scheduled_in, delta in variants:
+        out = run("post", text, "--scheduled-in", scheduled_in)
+        dttm = datetime.utcnow() + delta
+        assert out.startswith(f"Toot scheduled for: {str(dttm)[:16]}")
+        datetimes.append(dttm)
+
+    scheduled = api.scheduled_statuses(app, user)
+    scheduled = [s for s in scheduled if s["params"]["text"] == text]
+    scheduled = sorted(scheduled, key=lambda s: s["scheduled_at"])
+    assert len(scheduled) == 8
+
+    for expected, status in zip(datetimes, scheduled):
+        actual = datetime.strptime(status["scheduled_at"], "%Y-%m-%dT%H:%M:%S.%fZ")
+        delta = expected - actual
+        assert delta.total_seconds() < 5
+
+
+def test_post_language(app, user, run):
+    out = run("post", "test", "--language", "hr")
+    status_id = _posted_status_id(out)
+    status = api.fetch_status(app, user, status_id)
+    assert status["language"] == "hr"
+
+    out = run("post", "test", "--language", "zh")
+    status_id = _posted_status_id(out)
+    status = api.fetch_status(app, user, status_id)
+    assert status["language"] == "zh"
+
+
 def test_media_attachments(app, user, run):
     assets_dir = path.realpath(path.join(path.dirname(__file__), "assets"))
 
@@ -183,10 +230,12 @@ def test_media_attachments(app, user, run):
 
     [a1, a2, a3, a4] = status["media_attachments"]
 
-    assert a1["meta"]["original"]["size"] == "50x50"
-    assert a2["meta"]["original"]["size"] == "50x60"
-    assert a3["meta"]["original"]["size"] == "50x70"
-    assert a4["meta"]["original"]["size"] == "50x80"
+    # Pleroma doesn't send metadata
+    if "meta" in a1:
+        assert a1["meta"]["original"]["size"] == "50x50"
+        assert a2["meta"]["original"]["size"] == "50x60"
+        assert a3["meta"]["original"]["size"] == "50x70"
+        assert a4["meta"]["original"]["size"] == "50x80"
 
     assert a1["description"] == "Test 1"
     assert a2["description"] == "Test 2"
@@ -211,8 +260,11 @@ def test_media_attachment_without_text(mock_read, mock_ml, app, user, run):
     assert status["content"] == ""
 
     [attachment] = status["media_attachments"]
-    assert attachment["meta"]["original"]["size"] == "50x50"
-    assert attachment["description"] is None
+    assert not attachment["description"]
+
+    # Pleroma doesn't send metadata
+    if "meta" in attachment:
+        assert attachment["meta"]["original"]["size"] == "50x50"
 
 
 def test_delete_status(app, user, run):
@@ -323,14 +375,21 @@ def test_whoami(user, run):
     out = run("whoami")
     # TODO: test other fields once updating account is supported
     assert f"@{user.username}" in out
-    assert f"http://localhost:3000/@{user.username}" in out
+    assert f"http://{HOSTNAME}/@{user.username}" in out
 
 
-def test_whois(friend, run):
-    out = run("whois", friend.username)
+def test_whois(app, friend, run):
+    variants = [
+        friend.username,
+        f"@{friend.username}",
+        f"{friend.username}@{app.instance}",
+        f"@{friend.username}@{app.instance}",
+    ]
 
-    assert f"@{friend.username}" in out
-    assert f"http://localhost:3000/@{friend.username}" in out
+    for username in variants:
+        out = run("whois", username)
+        assert f"@{friend.username}" in out
+        assert f"http://{HOSTNAME}/@{friend.username}" in out
 
 
 def test_search_account(friend, run):
@@ -384,7 +443,7 @@ def strip_ansi(string):
 
 
 def _posted_status_id(out):
-    pattern = re.compile(r"Toot posted: http://([^/]+)/@([^/]+)/(.+)")
+    pattern = re.compile(r"Toot posted: http://([^/]+)/([^/]+)/(.+)")
     match = re.search(pattern, out)
     assert match
 
